import { prisma } from "@/prisma/db"
import { Prisma} from "@prisma/client"

type likeType = Prisma.LikeUncheckedCreateInput

/**
 * Creates like if user has not liked this post.
 * Deletes like if user has liked post already.
 * 
 */

export async function putLike(like: likeType){
//check if like exists by this user and for this post
// if exists delete
//if not create
    try{
        const actualLike = await prisma.like.findFirst({
            where: {
                id: like.id,
                postId: like.postId,
                author: like.author
            }
            })

            if(actualLike == null){
                throw Error("Message was not liked by this user")
            }
        
            prisma.like.delete({
                where: {
                    id: actualLike?.id
                }
            })

            prisma.message.update({
                where: {
                    id: like.postId
                },
                data:{
                    likeCount: {increment: 1}
                }
            })

    } catch{
        prisma.like.create({
            data:{
                postId: like.postId,
                author: like.author, 
                gameId: like.gameId
            }
        })

        prisma.message.update({
            where: {
                id: like.postId
            },
            data:{
                likeCount: {increment: -1}
            }
        })
    }


}
